==> magpie-data-0.10.2-sources.jar: io/openraven/magpie/data/aws/elb/ElasticLoadBalancingLoadBalancer.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.elb;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.elasticloadbalancing.model.LoadBalancerDescription;


@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = ElasticLoadBalancingLoadBalancer.TABLE_NAME)
public class ElasticLoadBalancingLoadBalancer extends AWSResource {
  protected static final String TABLE_NAME = "awselasticloadbalancingloadbalancer";
    public static final String RESOURCE_TYPE = "AWS::ElasticLoadBalancing::LoadBalancer";
    private static final String ARN_FORMAT = "arn:aws:elasticloadbalancing:%s:%s:loadbalancer/%s";

    @SuppressWarnings("unused")
    public ElasticLoadBalancingLoadBalancer() {
    this.resourceType = RESOURCE_TYPE;
    }

    public ElasticLoadBalancingLoadBalancer(LoadBalancerDescription loadBalancer, String region, String accountId) {
        this.resourceName = loadBalancer.dnsName();
        this.resourceId = loadBalancer.loadBalancerName();
        this.awsRegion = region;
        this.awsAccountId = accountId;
        this.resourceType = RESOURCE_TYPE;
        this.arn = String.format(ARN_FORMAT, region, accountId, loadBalancer.loadBalancerName());
        this.configuration = PayloadUtils.update(loadBalancer);
        this.createdIso = loadBalancer.createdTime();
    }
}

==> magpie-data-0.11.2-sources.jar: io/openraven/magpie/data/aws/elb/ElasticLoadBalancingLoadBalancer.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.elb;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.elasticloadbalancing.model.LoadBalancerDescription;


@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = ElasticLoadBalancingLoadBalancer.TABLE_NAME)
public class ElasticLoadBalancingLoadBalancer extends AWSResource {
  protected static final String TABLE_NAME = "awselasticloadbalancingloadbalancer";
    public static final String RESOURCE_TYPE = "AWS::ElasticLoadBalancing::LoadBalancer";
    private static final String ARN_FORMAT = "arn:aws:elasticloadbalancing:%s:%s:loadbalancer/%s";

    @SuppressWarnings("unused")
    public ElasticLoadBalancingLoadBalancer() {
    this.resourceType = RESOURCE_TYPE;
    }

    public ElasticLoadBalancingLoadBalancer(LoadBalancerDescription loadBalancer, String region, String accountId) {
        this.resourceName = loadBalancer.dnsName();
        this.resourceId = loadBalancer.loadBalancerName();
        this.awsRegion = region;
        this.awsAccountId = accountId;
        this.resourceType = RESOURCE_TYPE;
        this.arn = String.format(ARN_FORMAT, region, accountId, loadBalancer.loadBalancerName());
        this.configuration = PayloadUtils.update(loadBalancer);
        this.createdIso = loadBalancer.createdTime();
    }
}
